@@ -33,6 +33,7 @@ __all__ = (
     "OriginManifestTypeType",
     "PlaybackModeType",
     "RelativePositionType",
+    "ScheduleEntryTypeType",
     "TypeType",
 )
 
@@ -48,6 +49,7 @@ ListVodSourcesPaginatorName = Literal["list_vod_sources"]
 MessageTypeType = Literal["SPLICE_INSERT"]
 ModeType = Literal["BEHIND_LIVE_EDGE", "OFF"]
 OriginManifestTypeType = Literal["MULTI_PERIOD", "SINGLE_PERIOD"]
-PlaybackModeType = Literal["LOOP"]
+PlaybackModeType = Literal["LINEAR", "LOOP"]
 RelativePositionType = Literal["AFTER_PROGRAM", "BEFORE_PROGRAM"]
+ScheduleEntryTypeType = Literal["FILLER_SLATE", "PROGRAM"]
 TypeType = Literal["DASH", "HLS"]
